@@ -128,7 +128,7 @@ class UserInformation(BaseModel):
         db_table = 'user_information'
 
 
-class Roles(BaseModel):
+class Role(BaseModel):
     """"
     角色表
     """
@@ -147,7 +147,7 @@ class Roles(BaseModel):
         verbose_name = "角色"
 
 
-class UserRoles(BaseModel):
+class UserRole(BaseModel):
     """
     用户角色表
     """
@@ -155,7 +155,7 @@ class UserRoles(BaseModel):
         verbose_name="用户ID"
     )
     role = models.ForeignKey(
-        Roles,
+        Role,
         on_delete=models.CASCADE,
         verbose_name="角色"
     )
