@@ -322,3 +322,10 @@ def mv_show_order(organization_id: int, data: dict):
         Department.objects.filter(id=item["id"], organization_id=organization_id).update(show_order=item["show_order"])
 
     return Resp()
+
+
+def get_all_chargers(organization_id):
+    return Resp(data=list(DepartmentUserMap.objects.filter(
+        department__organization_id=organization_id,
+    ).order_by("user_id").values_list("user_id", flat=True)))
+
