@@ -34,18 +34,19 @@ if __name__ == '__main__':
         return res
 
 
-    obj = DepartmentViewSet(1)
+    # obj = DepartmentViewSet(1)
     # print(obj.list("sub", 2))
     # print(obj.list("all"))
     # print(obj.list("all", department_name="o"))
-    # print(obj.create({"name": "前端o1", "parent_id": 2, "charger_id": 11}))
+    # print(obj.create({"name": "前端o99", "parent_id": 2}))
     # print(obj.retrieve(3))
-    # print(obj.update(2, {"name": "前端2", "parent_id": 4, "charger_id": None}))
+    # print(obj.update(18, {"name": "前端99", "parent_id": 2, "charger_id": None}))
     # print(obj.delete(2))
-    print(obj.move_show_order([{"id": 5, "show_order": 5}, {"id": 7, "show_order": 4}]))
+    # print(obj.move_show_order([{"id": 5, "show_order": 5}, {"id": 7, "show_order": 4}]))
     # print(obj.create_department_user(5, [1, 2, 3]))
     # print(obj.department_user_list(5,))
     # print(obj.delete_department_user(5, [11]))
+    # print(obj.get_chargers())
 
 
 
