@@ -19,7 +19,8 @@ from departments.utils.department_funcs import (
     add_department_user_map,
     get_department_user,
     delete_department_user_map,
-    mv_show_order
+    mv_show_order,
+    get_all_chargers
 )
 
 
@@ -51,7 +52,7 @@ class DepartmentViewSet(object):
     def create(self, data: dict):
         """
         创建部门
-        :param data: {"name": "部门名称", "parent_id": "上一级部门id", "charger_id": "负责人id"}
+        :param data: {"name": "部门名称", "parent_id": "上一级部门id"}
         :return:
         """
         data["organization_id"] = self.organization_id
@@ -112,3 +113,10 @@ class DepartmentViewSet(object):
         """
         return delete_department_user_map(self.organization_id, department_id, user_ids)
 
+    def get_chargers(self):
+        """
+        获取部门负责人列表
+        :return:
+        """
+        return get_all_chargers(self.organization_id)
+
